@@ -9,6 +9,8 @@ our @EXPORT = qw(
     $VIEW_LIMIT
     $FEED_LIMIT
     $ROLE_LIMIT
+    $ACTION_LIMIT
+    $ACTION_PARAM_LIMIT
     $COLUMN_LIMIT
     $RECORD_LIMIT
     $INSERT_LIMIT
@@ -26,6 +28,8 @@ our $VIEW_LIMIT = 100;
 our $FEED_LIMIT = 100;
 our $ROLE_LIMIT = 100;
 our $COLUMN_LIMIT = 40;
+our $ACTION_LIMIT = 40;
+our $ACTION_PARAM_LIMIT = 100;
 our $INSERT_LIMIT = 20;
 our $RECORD_LIMIT = 200;
 our $POST_LEN_LIMIT = 1_000_000; # 1 MB
